@@ -1,8 +1,8 @@
 /*
- *  kaevent.h  -  represents calendar events
+ *  kaevent.h  -  represents KAlarm calendar events
  *  This file is part of kalarmcal library, which provides access to KAlarm
  *  calendar data.
- *  SPDX-FileCopyrightText: 2001-2019 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -187,7 +187,7 @@ class KALARMCAL_EXPORT KAEvent
 {
 public:
     /** A list of pointers to KAEvent objects. */
-    typedef QVector<KAEvent *> List;
+    using List = QVector<KAEvent *>;
 
     /** Flags for use in D-Bus calls, etc. Flags may be combined by OR'ing them together. */
     enum Flag {
@@ -209,7 +209,8 @@ public:
         WORK_TIME_ONLY  = 0x8000,  //!< trigger the alarm only during working hours
         DISPLAY_COMMAND = 0x10000, //!< display command output in the alarm window
         REMINDER_ONCE   = 0x20000, //!< only trigger the reminder on the first recurrence
-        DONT_SHOW_ERROR = 0x40000  //!< do not notify command alarm errors to user
+        DONT_SHOW_ERROR = 0x40000, //!< do not notify command alarm errors to user
+        NOTIFY          = 0x80000  //!< use the standard notification system instead of alarm message window
 
                           // IMPORTANT: if any values are added to this list, ensure that the
                           //            additional enum values in KAEventPrivate are also adjusted.
@@ -308,6 +309,7 @@ public:
     /** Construct an event and initialise with the specified parameters.
      *  @param dt    start date/time. If @p dt is date-only, or if #ANY_TIME flag
      *               is specified, the event will be date-only.
+     *  @param name  name of the alarm.
      *  @param text  alarm message (@p action = #MESSAGE);
      *               file to display (@p action = #FILE);
      *               command to execute (@p action = #COMMAND);
@@ -325,7 +327,32 @@ public:
      *                        to the instance; call endChanges() when changes
      *                        are complete.
      */
-    KAEvent(const KADateTime &dt, const QString &text, const QColor &bg, const QColor &fg,
+    KAEvent(const KADateTime &dt, const QString &name, const QString &text,
+            const QColor &bg, const QColor &fg, const QFont &font,
+            SubAction action, int lateCancel, Flags flags, bool changesPending = false);
+
+    /** Construct an event and initialise with the specified parameters.
+     *  @param dt    start date/time. If @p dt is date-only, or if #ANY_TIME flag
+     *               is specified, the event will be date-only.
+     *  @param text  alarm message (@p action = #MESSAGE);
+     *               file to display (@p action = #FILE);
+     *               command to execute (@p action = #COMMAND);
+     *               email body (@p action = #EMAIL);
+     *               audio file (@p action = #AUDIO).
+     *  @param bg    background color (for display alarms, ignored otherwise).
+     *  @param fg    foreground color (for display alarms, ignored otherwise).
+     *  @param font  font (for display alarms, ignored otherwise). Ignored if
+     *               #DEFAULT_FONT flag is specified.
+     *  @param action         alarm action type.
+     *  @param lateCancel     late-cancellation period (minutes), else 0.
+     *  @param flags          OR of #Flag enum values.
+     *  @param changesPending true to inhibit automatic calculations and data
+     *                        updates until further changes have been applied
+     *                        to the instance; call endChanges() when changes
+     *                        are complete.
+     *  @deprecated Use the other constructor.
+     */
+    KALARMCAL_DEPRECATED KAEvent(const KADateTime &dt, const QString &text, const QColor &bg, const QColor &fg,
             const QFont &font, SubAction action, int lateCancel, Flags flags, bool changesPending = false);
 
     /** Construct an event and initialise it from a KCalendarCore::Event.
@@ -555,6 +582,20 @@ public:
      */
     bool autoClose() const;
 
+    /** Enable the notification system to be used for a display alarm, instead
+     *  of displaying a window.
+     *  @see notify()
+     */
+    void setNotify(bool useNotify);
+
+    /** Return whether the notification system is used instead of displaying
+     *  a window, for a display alarm.
+     *  @return @c true if it is a display alarm and it uses the notification
+     *          system
+     *  @see setNotify()
+     */
+    bool notify() const;
+
     /** Set the Akonadi item ID of the email which the alarm is related to.
      */
     void setAkonadiItemId(Akonadi::Item::Id id);
@@ -563,6 +604,9 @@ public:
      */
     Akonadi::Item::Id akonadiItemId() const;
 
+    /** Return the alarm's name. */
+    QString name() const;
+
     /** Return the alarm's text. Its significance depends on the type of alarm;
      *  alternatively, use message(), displayMessage(), fileName() or command(),
      *  which incorporate checks on alarm type.
@@ -752,8 +796,9 @@ public:
     /** Return the alarm template's name.
      *  @return template name, or empty if not a template
      *  @see setTemplate()
+     *  @deprecated Use name() instead.
      */
-    QString templateName() const;
+    KALARMCAL_DEPRECATED QString templateName() const;
 
     /** Return whether the alarm template does not specify a time.
      *  @return @c true if no time is specified, i.e. the normal default alarm time will
